@@ -75,6 +75,7 @@ class TestCMFormatDescription(TestCase):
         self.assertEqual(CoreMedia.kCMVideoCodecType_Cinepak, fourcc(b"cvid"))
         self.assertEqual(CoreMedia.kCMVideoCodecType_JPEG, fourcc(b"jpeg"))
         self.assertEqual(CoreMedia.kCMVideoCodecType_JPEG_OpenDML, fourcc(b"dmb1"))
+        self.assertEqual(CoreMedia.kCMVideoCodecType_JPEG_XL, fourcc(b"jxlc"))
         self.assertEqual(CoreMedia.kCMVideoCodecType_SorensonVideo, fourcc(b"SVQ1"))
         self.assertEqual(CoreMedia.kCMVideoCodecType_SorensonVideo3, fourcc(b"SVQ3"))
         self.assertEqual(CoreMedia.kCMVideoCodecType_H263, fourcc(b"h263"))
@@ -268,6 +269,8 @@ class TestCMFormatDescription(TestCase):
             CoreMedia.kCMTaggedBufferGroupFormatType_TaggedBufferGroup, fourcc(b"tbgr")
         )
 
+        self.assertEqual(CoreMedia.kCMMediaType_AuxiliaryPicture, fourcc(b"auxv"))
+
     @min_os_level("10.7")
     def test_constants10_7(self):
         self.assertIsInstance(
@@ -633,6 +636,24 @@ class TestCMFormatDescription(TestCase):
             CoreMedia.kCMFormatDescriptionExtension_HasAdditionalViews, str
         )
 
+    @min_os_level("15.0")
+    def test_constants15_0(self):
+        self.assertIsInstance(
+            CoreMedia.kCMFormatDescriptionExtension_ProjectionKind, str
+        )
+        self.assertIsInstance(
+            CoreMedia.kCMFormatDescriptionProjectionKind_Rectilinear, str
+        )
+        self.assertIsInstance(
+            CoreMedia.kCMFormatDescriptionExtension_ViewPackingKind, str
+        )
+        self.assertIsInstance(
+            CoreMedia.kCMFormatDescriptionViewPackingKind_SideBySide, str
+        )
+        self.assertIsInstance(
+            CoreMedia.kCMFormatDescriptionViewPackingKind_OverUnder, str
+        )
+
     def test_structs(self):
         v = CoreMedia.CMVideoDimensions()
         self.assertEqual(v.width, 0)
